@@ -1,15 +1,17 @@
 """xontrib tests, such as they are"""
 import sys
+
 import pytest
-from xonsh.xontribs import xontrib_metadata, xontrib_context
+
+from xonsh.xontribs import (
+    xontrib_context,
+    xontribs_load,
+    xontribs_loaded,
+    xontribs_main,
+)
 
 
-def test_load_xontrib_metadata():
-    # Simply tests that the xontribs JSON files isn't malformed.
-    xontrib_metadata()
-
-
-@pytest.yield_fixture
+@pytest.fixture
 def tmpmod(tmpdir):
     """
     Same as tmpdir but also adds/removes it to the front of sys.path.
@@ -77,3 +79,39 @@ hello = 'world'
 
     ctx = xontrib_context("script")
     assert ctx == {"hello": "world"}
+
+
+def test_xontrib_load(tmpmod):
+    """
+    Test that .xsh xontribs are loadable
+    """
+    with tmpmod.mkdir("xontrib").join("script.xsh").open("w") as x:
+        x.write(
+            """
+hello = 'world'
+"""
+        )
+
+    xontribs_load(["script"])
+    assert "script" in xontribs_loaded()
+
+
+def test_xontrib_load_dashed(tmpmod):
+    """
+    Test that .xsh xontribs are loadable
+    """
+    with tmpmod.mkdir("xontrib").join("scri-pt.xsh").open("w") as x:
+        x.write(
+            """
+hello = 'world'
+"""
+        )
+
+    xontribs_load(["scri-pt"])
+    assert "scri-pt" in xontribs_loaded()
+
+
+def test_xontrib_list(xession, capsys):
+    xontribs_main(["list"])
+    out, err = capsys.readouterr()
+    assert "abbrevs" in out
